summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTharre <tharre3@gmail.com>2018-05-24 14:26:01 +0200
committerTharre <tharre3@gmail.com>2018-05-24 15:42:52 +0200
commite594ae7ee261bd3359d8cce55deda989bcb33206 (patch)
tree896a710259da6c47ca44a584afe847c9d10c96a6
parentcbc9019c96f2412ce3c6ec941726a4051e8d842a (diff)
downloadsepm-groupproject-e594ae7ee261bd3359d8cce55deda989bcb33206.tar.gz
sepm-groupproject-e594ae7ee261bd3359d8cce55deda989bcb33206.tar.xz
sepm-groupproject-e594ae7ee261bd3359d8cce55deda989bcb33206.zip
Change OperationService rankVehicle() #25963
Taken an opCode instead of a operationId, since we need the ranking before the operation is created.
-rw-r--r--src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationService.java8
-rw-r--r--src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationServiceImpl.java2
2 files changed, 5 insertions, 5 deletions
diff --git a/src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationServiceImpl.java b/src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationServiceImpl.java
index 4663d76..e1d6f29 100644
--- a/src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationServiceImpl.java
+++ b/src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationServiceImpl.java
@@ -122,7 +122,7 @@ public class OperationServiceImpl implements OperationService {
}
@Override
- public SortedSet<Vehicle> rankVehicles(long operationId)
+ public SortedSet<Vehicle> rankVehicles(String opCode)
throws InvalidOperationException, ServiceException {
throw new UnsupportedOperationException();
}
diff --git a/src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationService.java b/src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationService.java
index 98a2068..4b7e630 100644
--- a/src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationService.java
+++ b/src/main/java/at/ac/tuwien/sepm/assignment/groupphase/einsatzverwaltung/service/OperationService.java
@@ -48,15 +48,15 @@ public interface OperationService {
throws InvalidOperationException, ServiceException;
/**
* Get all available vehicles, sorted by how well they fit to the given operation, starting with
* the best fitting.
*
* @param operationId id of the operation that is used to determine the ranking
* @return a sorted list containing all available vehicles
* @throws InvalidOperationException if the operationId is invalid or does not exist
* @throws ServiceException if loading the stored vehicles failed
*/
- SortedSet<Vehicle> rankVehicles(long operationId)
+ SortedSet<Vehicle> rankVehicles(String opCode)
throws InvalidOperationException, ServiceException;
/**
@@ -48,15 +48,15 @@ public interface OperationService {
throws InvalidOperationException, ServiceException;
/**
- * Get all available vehicles, sorted by how well they fit to the given operation, starting with
+ * Get all available vehicles, sorted by how well they fit to the given opCode, starting with
* the best fitting.
*
@@ -48,15 +48,15 @@ public interface OperationService {
* the best fitting.
*
- * @param operationId id of the operation that is used to determine the ranking
+ * @param opCode the operation code that is used to determine the ranking
* @return a sorted list containing all available vehicles
@@ -48,15 +48,15 @@ public interface OperationService {
* @return a sorted list containing all available vehicles
- * @throws InvalidOperationException if the operationId is invalid or does not exist
+ * @throws InvalidOperationException if the opCode is invalid
* @throws ServiceException if loading the stored vehicles failed
*/